pub struct ClientRecord {
pub client_info: Implementation,
pub connected_at: DateTime<Utc>,
pub last_seen: DateTime<Utc>,
}Expand description
Client connection record with timestamp tracking
Fields
client_info: Implementationconnected_at: DateTime<Utc>last_seen: DateTime<Utc>Trait Implementations
Sourceimpl Clone for ClientRecord
impl Clone for ClientRecord
Sourcefn clone(&self) -> ClientRecord
fn clone(&self) -> ClientRecord
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClientRecord
impl Debug for ClientRecord
Sourceimpl<'de> Deserialize<'de> for ClientRecord
impl<'de> Deserialize<'de> for ClientRecord
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ClientRecord, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ClientRecord, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ClientRecord
impl JsonSchema for ClientRecord
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for ClientRecord
impl Serialize for ClientRecord
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more